Evaluates the normalized semicircle slab density on the standardized interval \([-1,1]\).

semicircle_kernel(u)

Arguments

u

A numeric vector of standardized coefficient values.

Details

The density is $$ K_S(u)=\frac{2}{\pi}\sqrt{1-u^2}I(|u|<1). $$ It is symmetric, integrates to one, and is more dispersed than the Wendland component used in the package. For a support scale \(\beta>0\), the corresponding density for a coefficient \(\theta\) is \(g_S(\theta;\beta)=\beta^{-1}K_S(\theta/\beta)\).

Value

A numeric vector of the same length as u, containing the density values.

References

Sanyal, N. (2026). Resolution-Adaptive Compact-Support Priors for Bayesian Wavelet Denoising: A Wendland-Semicircle Slab Mixture for Low-SNR Signal Recovery. Axioms, 15(9), 678. <DOI:10.3390/axioms15090678>

Author

Nilotpal Sanyal

Examples

u <- seq(-1.2, 1.2, length.out = 7)
semicircle_kernel(u)
#> [1] 0.0000000 0.3819719 0.5834717 0.6366198 0.5834717 0.3819719 0.0000000