wendland_kernel.RdEvaluates the normalized compactly supported Wendland-type slab density on the standardized interval \([-1,1]\).
wendland_kernel(u)The density is $$ K_W(u)=\frac{3}{2}(1-|u|)^4(1+4|u|) I(|u|<1). $$ It is symmetric, integrates to one, is concentrated near zero, and is exactly zero outside the open unit interval. For a support scale \(\beta>0\), the corresponding density for a coefficient \(\theta\) is \(g_W(\theta;\beta)=\beta^{-1}K_W(\theta/\beta)\).
A numeric vector of the same length as u, containing the density
values.
Sanyal, N. (2026). Resolution-Adaptive Compact-Support Priors for Bayesian Wavelet Denoising: A Wendland-Semicircle Slab Mixture for Low-SNR Signal Recovery. Axioms, 15(9), 678. <DOI:10.3390/axioms15090678>
u <- seq(-1.2, 1.2, length.out = 7)
wendland_kernel(u)
#> [1] 0.00000 0.01008 0.50544 1.50000 0.50544 0.01008 0.00000